clear all
clc

% ----------------- NAVODILA UPORABE PROGRAMA ---------------------

% Uporabnik izbere kontinent in kriteri ocenjevanja primernosti projekcije za izbran kontinent

% Vsak kontinent je predstavljen s svojim indentifikacijskih tevilom:
% 1 - EVROPA
% 2 - AZIJA
% 3 - EVRAZIJA
% 4 - AFRIKA
% 5 - SEVERNA AMERIKA
% 6 - JUNA AMERIKA
% 7 - AVSTRALIJA
% 8 - ANTARKTIKA

% ------------ IZBIRA KONTINENTA ----------
kontinent = 4; %vnesi indentifikacijsko tevilko eljenega kontinenta 

% Ocenjevalni kriteri ima svojo zaporedno tevilo
% 1 - ohranitev oblike kontinenta
% 2 - minimizacija dolinskih deformacij v smeri meridianov
% 3 - minimizacija dolinskih deformacij v smeri paralel
% 4 - minimizacija kotnih deformacij na obmoju kontinenta

% ------------ IZBIRA KRITERIJA ------------
kriterij = 1; % vnesi zaporedno tevilko izbranega kriterija


%branje podatkov za izbrano celino
[ Fi, La, Fi_0, La_0, Fi_1, Fi_2, h0, Fi_S, st_RT] = Izbira_celine(kontinent);
 fprintf('Izbran kontinent je aproksimiran s %d REFERENNIMI TOKAMI \n', st_RT)
%parametri GRS80 elipsoida
a = 6378137.000;
f = 1/298.257223563;
[b, eks] = Parametri_b_eks(a,f);

%radi zemlje je taken, da je povrina elipsoida enaka povrini krogle
Qp = 1-((1-eks^2)/(2*eks))*log((1-eks)/(1+eks));
Rq = a*(Qp/2)^(1/2);

%--------------------------------------------------------------------------
%-------------------------- BONNOVA PROJEKCIA ----------------------------
%--------------------------------------------------------------------------
st_n = size (Fi);
st_m = size (La);

for i = 1: st_n(2)
    for j = 1:st_m(2)
        
[Y_B, X_B, P_B, omega_dms, Epsilon_A1, Eps_m, Eps_n] = BONN_proj(Fi_0, La_0, Fi(i), La(j), a, f, eks, kontinent);
y_B(i,j) = Y_B;
x_B(i,j) = X_B;
omega_B(i,j) = omega_dms;
p_B(i,j) = P_B;
Epsilon_A1_B(i,j) = Epsilon_A1;
Eps_m_B(i,j) = Eps_m;
Eps_n_B(i,j) = Eps_n;
    end
end
% y_B
% x_B
% p_B
% omega_B
% Epsilon_A1_B
% Eps_m_B
% Eps_n_B


%inverzna funkcija kontrola
st_ = size (y_B);
for i = 1: st_(1)
    for j = 1:st_(2)
[Fi_, La_] = Bonn_inverz( a,f, eks, Fi_0, La_0, y_B(i,j), x_B(i,j), kontinent);

Fi_B(i,j) = Fi_;
La_B(i,j) = La_;
    end
end
%Fi_B
%La_B

%--------------------------------------------------------------------------
%-------------- LAMBERTOVA EKVIVALENTNA AZIMUTALNA PROJEKCIA --------------
%--------------------------------------------------------------------------
for i = 1: st_n(2)
    for j = 1:st_m(2)
        
[Y_L, X_L, P_L, omega_dms, Epsilon_A1, Eps_m, Eps_n] = LAMBERT_proj(Fi_0, La_0, Fi(i), La(j), a, f, eks, kontinent);

y_L(i,j) = Y_L;
x_L(i,j) = X_L;
omega_L(i,j) = omega_dms;
p_L(i,j) = P_L;
Epsilon_A1_L(i,j) = Epsilon_A1;
Eps_m_L(i,j) = Eps_m;
Eps_n_L(i,j) = Eps_n;

    end
end
% y_L
% x_L
% p_L
% omega_L
% Epsilon_A1_L
% Eps_m_L
% Eps_n_L

%inverzna funkcija kontrola
st_ = size (y_L);
for i = 1: st_(1)
    for j = 1:st_(2)
[ Fi_dms La_dms ] = Lambert_inv(Fi_0, La_0, y_L(i,j), x_L(i,j), a, f, eks, kontinent);
Fi_L(i,j) = Fi_dms;
La_L(i,j) = La_dms;
    end
end
%Fi_L
%La_L

%--------------------------------------------------------------------------
%---------------- ALBERSOVA EKVIVALENTNA KONUSNA PROJEKCIA ----------------
%--------------------------------------------------------------------------
for i = 1: st_n(2)
    for j = 1:st_m(2)
        
[Y_A, X_A, P_A, omega_dms, Epsilon_A1, Eps_m, Eps_n] = ALBERS_proj( Fi_0, La_0, Fi_1, Fi_2, Fi(i), La(j), a, f, eks);

y_A(i,j) = Y_A;
x_A(i,j) = X_A;
omega_A(i,j) = omega_dms;
p_A (i,j)= P_A;
Epsilon_A1_A(i,j) = Epsilon_A1;
Eps_m_A(i,j) = Eps_m;
Eps_n_A(i,j) = Eps_n;

    end
end

% y_A
% x_A
% p_A
% omega_A
% Epsilon_A1_A
% Eps_m_A
% Eps_n_A


%inverzna funkcija kontrola
st_ = size (y_A);
for i = 1: st_(1)
    for j = 1:st_(2)
[ Fi_dms, La_dms ] = Albers_inv( Fi_0, La_0, Fi_1, Fi_2, x_A(i,j), y_A(i,j), a, f, eks);
Fi_A(i,j) = Fi_dms;
La_A(i,j) = La_dms;
    end
end
%Fi_A
%La_A



%--------------------------------------------------------------------------
%--------------- CILINDRINA EKVIVALENTNA PRENA PROJEKCIJA ---------------
%--------------------------------------------------------------------------
for i = 1: st_n(2)
    for j = 1:st_m(2)
        
[X_Cp, Y_Cp, P_Cp, omega_dms, Epsilon_A1, Eps_m, Eps_n] = CILIND_PRECNA_proj(Fi_0, La_0, Fi(i), La(j), a, f, eks, h0);

y_Cp(i,j) = Y_Cp;
x_Cp(i,j) = X_Cp;
omega_Cp(i,j)= omega_dms;
p_Cp(i,j) = P_Cp;
Epsilon_A1_Cp(i,j) = Epsilon_A1;
Eps_m_Cp(i,j) = Eps_m;
Eps_n_Cp(i,j) = Eps_n;

    end
end
% y_Cp
% x_Cp
% p_Cp
% omega_Cp
% Epsilon_A1_Cp
% Eps_m_Cp
% Eps_n_Cp

%inverzna funkcija kontrola
st_ = size (y_Cp);
for i = 1: st_(1)
    for j = 1:st_(2)
[ Fi_dms, La_dms ] = Cilind_prec_inv(Fi_0, La_0, x_Cp(i,j), y_Cp(i,j), h0, Rq);
Fi_Cp(i,j) = Fi_dms;
La_Cp(i,j) = La_dms;
    end
end
%Fi_Cp
%La_Cp

%--------------------------------------------------------------------------
%--------------- CILINDRINA EKVIVALENTNA POKONNA PROJEKCIJA -------------
%--------------------------------------------------------------------------

for i = 1: st_n(2)
    for j = 1:st_m(2)
        
[X_Cn, Y_Cn, P_Cn, omega_dms, Epsilon_A1, Eps_m, Eps_n] = CILIND_POKONCNA_proj(Fi_0, La_0, Fi(i), La(j), a, f, eks, Fi_S);

y_Cn(i,j) = Y_Cn;
x_Cn(i,j) = X_Cn;
omega_Cn(i,j)= omega_dms;
p_Cn(i,j) = P_Cn;
Epsilon_A1_Cn(i,j) = Epsilon_A1;
Eps_m_Cn(i,j) = Eps_m;
Eps_n_Cn(i,j) = Eps_n;

    end
end
% y_Cn
% x_Cn
% p_Cn
% omega_Cn
% Epsilon_A1_Cn
% Eps_m_Cn
% Eps_n_Cn

%inverzna funkcija kontrola
st_ = size (y_Cn);
for i = 1: st_(1)
    for j = 1:st_(2)
[ Fi_dms, La_dms ] = Cilind_pokoncna_inv( Fi_0, La_0, x_Cn(i,j), y_Cn(i,j), a, eks, Fi_S);
Fi_Cn(i,j) = Fi_dms;
La_Cn(i,j) = La_dms;
    end
end
%Fi_Cn
%La_Cn

%--------------------------------------------------------------------------
%--------------------- KAVRAISKIY VI oz. WAGNER I PROJEKCIJA --------------
%--------------------------------------------------------------------------

for i = 1: st_n(2)
    for j = 1:st_m(2)
        
[Y_W, X_W, P_W, omega_dms, Epsilon_A1, Eps_m, Eps_n] = WAGNER_I(Fi_0, La_0, Fi(i), La(j), a, f, b, eks);

y_W(i,j) = Y_W;
x_W(i,j) = X_W;
omega_W(i,j)= omega_dms;
p_W(i,j) = P_W;
Epsilon_A1_W(i,j) = Epsilon_A1;
Eps_m_W(i,j) = Eps_m;
Eps_n_W(i,j) = Eps_n;

    end
end
% y_W
% x_W
% p_W
% omega_W
% Epsilon_A1_W
% Eps_m_W
% Eps_n_W

%-------------------------------------------------------------------------------------
%----------------------------- KONNI REZULTATI --------------------------------------
%-------------------------------------------------------------------------------------
[B, L, A, Cp, Cn, W, B_median, L_median, A_median, Cp_median, Cn_median, W_median, B_max, L_max, A_max,...
    Cp_max, Cn_max, W_max, B_std, L_std, A_std, Cp_std, Cn_std, W_std, B_SE, L_SE, A_SE, Cp_SE, Cn_SE, W_SE]...
    = Posredovanje_rezultatov( kriterij, kontinent, st_RT, Epsilon_A1_B, Epsilon_A1_L, Epsilon_A1_A, Epsilon_A1_Cp,...
    Epsilon_A1_Cn, Epsilon_A1_W, Eps_m_B, Eps_m_L, Eps_m_A, Eps_m_Cp, Eps_m_Cn, Eps_m_W, Eps_n_B, Eps_n_L, Eps_n_A,...
    Eps_n_Cp, Eps_n_Cn, Eps_n_W, omega_B, omega_L, omega_A, omega_Cp, omega_Cn, omega_W);

    
if kontinent == 3 
    Cp = 100; %V primeru kontinenta Evrazija, se cilindrine prene projekcije ne uporabi, za to se ji dodeli vrednost Cp = 100
    
elseif kontinent == 4 
    A = 100; %V primeru kontinenta Afrika, se Albersove projekcije ne uporabi, za to se ji dodeli vrednost A = 100
    
elseif kontinent == 8
    A = 100; %V primeru kontinenta Antartika je smiselno uporabljati le Lambertovo in Bonnovo projekciji, vse ostale pridobijo vrednost 100.
    Cp = 100;
    Cn = 100;
    W = 100;
else
end

%Razvrstivev rezultatov po velikosti od najmanjega do najvejega
%B, L, A, Cp, Cn, W
REZULTATI=[B L A Cp Cn W];
%disp('Stevila pred sortiranjem: ')
%disp(REZULTATI)
n=length(REZULTATI);
% naredis (n-1) prehodov
for j=1:1:n-1
    % primerjas vsako stevilko z naslednjo in po potrebi menjas
    for i=1:1:n-1
		if REZULTATI(i)>REZULTATI(i+1);
			temp=REZULTATI(i);
			REZULTATI(i)=REZULTATI(i+1);
			REZULTATI(i+1)=temp;
		end
    end
end
%disp('Seznam, posortiran narascajoce: ')
%disp(REZULTAT)

fprintf('\nRazvrstitev projekcij po primernosti uporabe glede na izbran kontinent in dodaten kriterij\n')
fprintf('\n    Ime projekcije         Srednja vr.    Std.     Mediana     Max        SE\n')
if REZULTATI(1) == B
   fprintf('1. BONNOVA projekcija      |  %f | %f | %f | %f | %f  \n', B, B_std, B_median, B_max, B_SE)
elseif REZULTATI(1) == L
   fprintf('1. LAMBERTOVA AZIM. proj.  |  %f | %f | %f | %f | %f  \n', L, L_std, L_median, L_max, L_SE)
elseif REZULTATI(1) == A
   fprintf('1. ALBERSOVA projekcija    |  %f | %f | %f | %f | %f  \n', A, A_std, A_median, A_max, A_SE)
elseif REZULTATI(1) == Cp
   fprintf('1. CILIN. EKVI. PRE. proj.|  %f | %f | %f | %f | %f  \n', Cp, Cp_std, Cp_median, Cp_max, Cp_SE)
elseif REZULTATI(1) == Cn
   fprintf('1. CILIN. EKVI. POK. proj. |  %f | %f | %f | %f | %f  \n', Cn, Cn_std, Cn_median, Cn_max, Cn_SE)
elseif REZULTATI(1) == W
   fprintf('1. WAGNER I projekcija     |  %f | %f | %f | %f | %f  \n', W, W_std, W_median, W_max, W_SE)
end

if REZULTATI(2) == B
   fprintf('2. BONNOVA projekcija      |  %f | %f | %f | %f | %f  \n', B, B_std, B_median, B_max, B_SE)
elseif REZULTATI(2) == L 
   fprintf('2. LAMBERTOVA AZIM. proj.  |  %f | %f | %f | %f | %f  \n', L, L_std, L_median, L_max, L_SE)
elseif REZULTATI(2) == A
   fprintf('2. ALBERSOVA projekcija    |  %f | %f | %f | %f | %f  \n', A, A_std, A_median, A_max, A_SE)
elseif REZULTATI(2) == Cp
   fprintf('2. CILIN. EKVI. PRE. proj.|  %f | %f | %f | %f | %f  \n', Cp, Cp_std, Cp_median, Cp_max, Cp_SE)
elseif REZULTATI(2) == Cn
   fprintf('2. CILIN. EKVI. POK. proj. |  %f | %f | %f | %f | %f  \n', Cn, Cn_std, Cn_median, Cn_max, Cn_SE)
elseif REZULTATI(2) == W
   fprintf('2. WAGNER I projekcija     |  %f | %f | %f | %f | %f  \n', W, W_std, W_median, W_max, W_SE)
end

if REZULTATI(3) == 100
    ;
elseif REZULTATI(3) == B
   fprintf('3. BONNOVA projekcija      |  %f | %f | %f | %f | %f  \n', B, B_std, B_median, B_max, B_SE)
elseif REZULTATI(3) == L
   fprintf('3. LAMBERTOVA AZIM. proj.  |  %f | %f | %f | %f | %f  \n', L, L_std, L_median, L_max, L_SE)
elseif REZULTATI(3) == A
   fprintf('3. ALBERSOVA projekcija    |  %f | %f | %f | %f | %f  \n', A, A_std, A_median, A_max, A_SE)
elseif REZULTATI(3) == Cp
   fprintf('3. CILIN. EKVI. PRE. proj.|  %f | %f | %f | %f | %f  \n', Cp, Cp_std, Cp_median, Cp_max, Cp_SE)
elseif REZULTATI(3) == Cn
   fprintf('3. CILIN. EKVI. POK. proj. |  %f | %f | %f | %f | %f  \n', Cn, Cn_std, Cn_median, Cn_max, Cn_SE)
elseif REZULTATI(3) == W
   fprintf('3. WAGNER I projekcija     |  %f | %f | %f | %f | %f  \n', W, W_std, W_median, W_max, W_SE)
end

if REZULTATI(4) == 100
    ;
elseif REZULTATI(4) == B
   fprintf('4. BONNOVA projekcija      |  %f | %f | %f | %f | %f  \n', B, B_std, B_median, B_max, B_SE)
elseif REZULTATI(4) == L
   fprintf('4. LAMBERTOVA AZIM. proj.  |  %f | %f | %f | %f | %f  \n', L, L_std, L_median, L_max, L_SE)
elseif REZULTATI(4) == A
   fprintf('4. ALBERSOVA projekcija    |  %f | %f | %f | %f | %f  \n', A, A_std, A_median, A_max, A_SE)
elseif REZULTATI(4) == Cp
   fprintf('4. CILIN. EKVI. PRE. proj.|  %f | %f | %f | %f | %f  \n', Cp, Cp_std, Cp_median, Cp_max, Cp_SE)
elseif REZULTATI(4) == Cn
   fprintf('4. CILIN. EKVI. POK. proj. |  %f | %f | %f | %f | %f  \n', Cn, Cn_std, Cn_median, Cn_max, Cn_SE)
elseif REZULTATI(4) == W
   fprintf('4. WAGNER I projekcija     |  %f | %f | %f | %f | %f  \n', W, W_std, W_median, W_max, W_SE)
end

if REZULTATI(5) == 100
    ;
elseif REZULTATI(5) == B
   fprintf('5. BONNOVA projekcija      |  %f | %f | %f | %f | %f  \n', B, B_std, B_median, B_max, B_SE)
elseif REZULTATI(5) == L
   fprintf('5. LAMBERTOVA AZIM. proj.  |  %f | %f | %f | %f | %f  \n', L, L_std, L_median, L_max, L_SE)
elseif REZULTATI(5) == A
   fprintf('5. ALBERSOVA projekcija    |  %f | %f | %f | %f | %f  \n', A, A_std, A_median, A_max, A_SE)
elseif REZULTATI(5) == Cp
   fprintf('5. CILIN. EKVI. PRE. proj.|  %f | %f | %f | %f | %f  \n', Cp, Cp_std, Cp_median, Cp_max, Cp_SE)
elseif REZULTATI(5) == Cn
   fprintf('5. CILIN. EKVI. POK. proj. |  %f | %f | %f | %f | %f  \n', Cn, Cn_std, Cn_median, Cn_max, Cn_SE)
elseif REZULTATI(5) == W
   fprintf('5. WAGNER I projekcija     |  %f | %f | %f | %f | %f  \n', W, W_std, W_median, W_max, W_SE)
end

if REZULTATI(6) == 100
    ;
elseif REZULTATI(6) == B
   fprintf('6. BONNOVA projekcija      |  %f | %f | %f | %f | %f  \n', B, B_std, B_median, B_max, B_SE)
elseif REZULTATI(6) == L
   fprintf('6. LAMBERTOVA AZIM. proj.  |  %f | %f | %f | %f | %f  \n', L, L_std, L_median, L_max, L_SE)
elseif REZULTATI(6) == A
   fprintf('6. ALBERSOVA projekcija    |  %f | %f | %f | %f | %f  \n', A, A_std, A_median, A_max, A_SE)
elseif REZULTATI(6) == Cp
   fprintf('6. CILIN. EKVI. PRE. proj.|  %f | %f | %f | %f | %f  \n', Cp, Cp_std, Cp_median, Cp_max, Cp_SE)
elseif REZULTATI(6) == Cn
   fprintf('6. CILIN. EKVI. POK. proj. |  %f | %f | %f | %f | %f  \n', Cn, Cn_std, Cn_median, Cn_max, Cn_SE)
elseif REZULTATI(6) == W
   fprintf('6. WAGNER I projekcija     |  %f | %f | %f | %f | %f \n', W, W_std, W_median, W_max, W_SE)
end

 
fprintf('\nZA IZRIS IZBRANEGA KONTINENTA POAKAJTE NEKAJ TRENUTKOV (3 izrisi) \n')
if kriterij == 1
    [ v ] = Izris_celine1( kontinent );
elseif kriterij == 2
    [ V ] = Izris_celine2( kontinent );
elseif kriterij == 3
    [ V ] = Izris_celine2( kontinent );
else
    [ v ] = Izris_celine1( kontinent );
end
